from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from django.contrib.auth.models import User
from django.forms import ModelForm
from . import models
from django.utils.html import format_html
from .forms import UploadExcelForm
import pandas as pd
from import_export.admin import ImportExportModelAdmin
from django.utils.safestring import mark_safe
from modeltranslation.admin import TranslationAdmin

class MetadataAdmin(ImportExportModelAdmin,TranslationAdmin,admin.ModelAdmin):
    list_display = [field.name for field in models.Metadata._meta.get_fields()]
    search_fields = ['slug']
    pass


admin.site.register(models.Metadata, MetadataAdmin)


class ContactFormAdmin(admin.ModelAdmin):
    list_display = [field.name for field in models.ContactForm._meta.get_fields()]

admin.site.register(models.ContactForm, ContactFormAdmin)

class BlogAdmin(ImportExportModelAdmin,admin.ModelAdmin):
    list_display = ['title', 'short_description', 'image_tag', 'publication_date', 'modified_date', 'slug']

    def image_tag(self, obj):
        if obj.image:
            return mark_safe(f'<img src="{obj.image.url}" width="100" />')
        return ''


    def get_form(self, request, obj=None, **kwargs):
        form = super().get_form(request, obj, **kwargs)
        form.base_fields['image'].widget.can_change_related = True
        return form

    image_tag.short_description = 'Image Preview'

    search_fields = ['slug','title']


admin.site.register(models.Blog,BlogAdmin)



class LinkAdmin(admin.ModelAdmin):
    list_display = [field.name for field in models.Link._meta.get_fields()]


admin.site.register(models.Link,LinkAdmin)


admin.site.register(models.Snippet)
admin.site.register(models.Post)